@@ -1,8 +1,8 @@
 from PIL import Image
 import numpy as np
 import torch
-from .nets.deeplab import DeepLab
-from .utils.data import decodePredicts
+from nets.deeplab import DeepLab
+from utils.data import decodePredicts
 from torchvision import transforms
 
 
@@ -12,15 +12,17 @@ def infer(img, model_pt):
     model.eval()
 
     model.load_state_dict(torch.load(model_pt, map_location="cpu"))
-    model.to(device)
+    if torch.cuda.is_available():
+        model.to(device)
 
     input_image = Image.open(img)
     preprocess = transforms.Compose([transforms.ToTensor()])
     input_tensor = preprocess(input_image)
     input_batch = input_tensor.unsqueeze(0)
-    input_batch.to(device)
+    if torch.cuda.is_available():
+        input_batch.to(device)
     predicts = model(input_batch)
     outs = decodePredicts(predicts, (1536, 512), 690)
     outs = outs.permute((0, 2, 3, 1).numpy().astype(np.uint8))
 
-    return outs
\ No newline at end of file
+    return outs
